#!/usr/bin/env python
# -*- coding: utf-8 -*-

# License Agreement
# This code is licensed under the outer restricted Tiss license:
#
#  Copyright [2014]-[2019] Thales Services under the Thales Inner Source Software License
#  (Version 1.0, InnerPublic -OuterRestricted the "License");
#
#  You may not use this file except in compliance with the License.
#
#  The complete license agreement can be requested at contact@punchplatform.com.
#
#  Refer to the License for the specific language governing permissions and limitations
#  under the License.

from abc import abstractmethod

from punch_api.dag import Node
from punch_api.datasets import InputDatasets, OutputDatasets
from punch_api.logger import print_error


class Source(Node):
    def __init__(self):
        """
        Override Node's dataclass __init__
        Classic Node's attributes are set by NodeRunner, not by __init__
        """
        pass

    @abstractmethod
    def execute(self, output_datasets: OutputDatasets) -> None:
        """Execute the node

        :param output_datasets: an empty custom object that is used to publish data to the outs with output.put()
        :return: None
        """

        print_error("execute(self, output_datasets) must be override by your own node.")
        raise NotImplementedError("abstract method execute")


class Function(Node):
    @abstractmethod
    def execute(
        self, input_datasets: InputDatasets, output_datasets: OutputDatasets
    ) -> None:
        """
        Execute the node

        :param input_datasets: a custom object containing the data from the connected input out
        :param output_datasets: an empty custom object that is used to publish data to the output outs with output.put()
        :return: None
        """

        print_error(
            "execute(self, input_datasets, output_datasets) must be override by your own node."
        )
        raise NotImplementedError("abstract method execute")



import prometheus_client


class Histogram:
    child: prometheus_client.Histogram

    def __init__(self, c: prometheus_client.Histogram, labels: list[str]) -> None:
        self.child = c.labels(*labels)

    def observe(self, o: float) -> None:
        self.child.observe(o)

    def time(self) -> prometheus_client.context_managers.Timer:
        return self.child.time()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['punch_api', 'punch_api.metrics']

package_data = \
{'': ['*']}

install_requires = \
['prometheus-client>=0.12.0,<0.13.0']

setup_kwargs = {
    'name': 'punch-api',
    'version': '8.0.1',
    'description': 'Punch Python and PySpark Public API',
    'long_description': None,
    'author': 'Punch',
    'author_email': 'contact@punchplatform.com',
    'maintainer': 'Punch',
    'maintainer_email': 'contact@punchplatform.com',
    'url': 'https://punchplatform.com',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10.4,<4.0.0',
}


setup(**setup_kwargs)
